/*
 *  XMail by Davide Libenzi ( Intranet and Internet mail server )
 *  Copyright (C) 1999,...,2002  Davide Libenzi
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Davide Libenzi <davidel@xmailserver.org>
 *
 */


#ifndef _CPUDEFINES_H
#define _CPUDEFINES_H



#ifdef XMAIL_X86

#include "SysCPUx86.h"

#else           // #ifdef XMAIL_X86
#ifdef XMAIL_SPARC

#include "SysCPUSPARC.h"

#else           // #ifdef XMAIL_SPARC
#ifdef XMAIL_PPC

#include "SysCPUPPC.h"

#else           // #ifdef XMAIL_PPC

#error CPU type not defined

#endif          // #ifdef XMAIL_PPC
#endif          // #ifdef XMAIL_SPARC
#endif          // #ifdef XMAIL_X86




#endif
